netapp_ontap.models.layout_requirement API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.layout_requirement`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LayoutRequirementSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LayoutRequirement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `aggregate_min_disks GET`

    Minimum number of disks to create an aggregate

    Example: 6

  `default GET`

    Indicates if this RAID type is the default

  `raid_group GET`

    The raid_group field of the layout_requirement.

  `raid_type GET`

    RAID type

    Valid choices:

    - raid_dp
    - raid_tec
    - raid4
    - raid0